summaryrefslogtreecommitdiffstats
path: root/os-plugins/plugins/vmchooser/files/run-virt.sh
diff options
context:
space:
mode:
Diffstat (limited to 'os-plugins/plugins/vmchooser/files/run-virt.sh')
-rw-r--r--os-plugins/plugins/vmchooser/files/run-virt.sh5
1 files changed, 3 insertions, 2 deletions
diff --git a/os-plugins/plugins/vmchooser/files/run-virt.sh b/os-plugins/plugins/vmchooser/files/run-virt.sh
index 41144edd..d7539701 100644
--- a/os-plugins/plugins/vmchooser/files/run-virt.sh
+++ b/os-plugins/plugins/vmchooser/files/run-virt.sh
@@ -87,8 +87,9 @@ vmostype=$(grep -io "<os param=.*\"" ${xml} | awk -F "\"" '{ print $2 }')
# Definition of the networking the client system is connected to
network_kind=$(grep -io "<network param=.*\"" ${xml} | awk -F "\"" '{ print $2 }')
-# Serial port defined (e.g. "ttyS0" or "autodetect")
-serial=$(grep -io "<serial port=.*\"" ${xml} | awk -F "\"" '{ print $2 }')
+# Serial/parallel ports defined (e.g. "ttyS0" or "autodetect")
+serial=$(grep -io "<serialport param=.*\"" ${xml} | awk -F "\"" '{ print $2 }')
+parallel=$(grep -io "<parport param=.*\"" ${xml} | awk -F "\"" '{ print $2 }')
# Declaration of default variables